---- QuerySessionCurrentInfo ----
select pg_catalog.current_database(),
       pg_catalog.current_schema(),
       current_timestamp::timestamp as current_timestamp
;


---- SchemaAges ----
select pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:schema_txid))) as schema_age, pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:sources_txid))) as sources_age
;


---- ListDatabases ----
select oid::bigint as id,
       xmin as state_number,
       datname as name,
       pg_catalog.pg_get_userbyid(datdba) as "owner"
from pg_catalog.pg_database
where not datistemplate
order by case when datname = pg_catalog.current_database() then -1::bigint else oid::bigint end
;


---- CurrentDatabaseComment ----
select D.description
from pg_catalog.pg_database N
  left join pg_catalog.pg_description D on N.oid = D.objoid and D.classoid = 'pg_catalog.pg_database'::regclass
where datname = pg_catalog.current_database()
;


---- ListSchemas ----
select N.oid::bigint as id,
       N.xmin as state_number,
       N.nspname as name,
       D.description,
       pg_catalog.pg_get_userbyid(N.nspowner) as "owner"
from pg_catalog.pg_namespace N
  left outer join pg_catalog.pg_external_schema ES on N.oid = ES.esoid
  left join pg_catalog.pg_description D on N.oid = D.objoid
  where ES.esoid is null
order by case when N.nspname = pg_catalog.current_schema() then -1::bigint else N.oid::bigint end
;


---- RetrievePermissions ----
select pg_catalog.has_table_privilege('pg_catalog.pg_user_info', 'select') user_ext

---- RetrieveUsers ----
select usesysid as user_id, usename as user_name,
  usesuper is_super, usecreatedb can_createdb,
  #[USER_EXT]: case when useconnlimit = 'UNLIMITED' then -1 ELSE useconnlimit::int end #: null #. conn_limit,
  valuntil valid_until, '{' || pg_catalog.array_to_string(useconfig, :array_delimiter) || '}' config
from #[USER_EXT]: pg_catalog.pg_user_info #: pg_catalog.pg_user #.
;


---- RetrieveExternalSchemas ----
select S.nspname as schema_name,
       S.oid as schema_id,
       S.xmin as state_number,
       ES.esdbname as database_name,
       ES.eskind as schema_kind,
       ES.esoptions as schema_options,
       D.description,
       pg_catalog.pg_get_userbyid(S.nspowner) as "owner"
from pg_catalog.pg_external_schema ES
  left join pg_catalog.pg_namespace S on ES.esoid = S.oid
  left join pg_catalog.pg_description D on S.oid = D.objoid
;


---- StateNumber ----
select pg_catalog.int8in(pg_catalog.xidout(L.transaction)) as transaction_id
from pg_catalog.pg_locks L
where L.transaction is not null
order by pg_catalog.age(L.transaction) desc
limit 1
;


---- CurrentXid ----
select pg_catalog.xidin(pg_catalog.int8out(pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(3)))::bigint + 3)) as current_txid
;


---- CheckSchemaChanges ----
select pg_catalog.age(C.last_tx) <= greatest(pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))), pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:src_tx)))) as has_changes from
(
  select X.last_tx as last_tx
  from (
    (
    select xmin as last_tx
      from pg_catalog.pg_type
      where typnamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(xmin)
      limit 1
    )
    union all
    (
    select xmin as last_tx
      from pg_catalog.pg_class
      where relnamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(xmin)
      limit 1
    )
    union all
    (
    select xmin as last_tx
      from pg_catalog.pg_proc
      where pronamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(xmin)
      limit 1
    )
    union all
    (
    select xmin as last_tx
      from pg_catalog.pg_operator
      where oprnamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(xmin)
      limit 1
    )
    union all
    (
    select A.xmin as last_tx
      from pg_catalog.pg_attribute A join pg_catalog.pg_class K on K.oid = A.attrelid
      where K.relnamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(A.xmin)
      limit 1
    )
    union all
    (
    select xmin as last_tx
      from pg_catalog.pg_constraint
      where connamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(xmin)
      limit 1
    )
    union all
    (
    select DE.xmin as last_tx
      from pg_catalog.pg_description DE,
           pg_catalog.pg_class DC
      where DC.oid = DE.objoid
        and DC.relnamespace = pg_catalog.oid(:schema_id)
        and DC.relkind in ('r', 'm', 'v')
      order by pg_catalog.age(DE.xmin)
        limit 1
    )
    union all
    (
    select D.xmin as last_tx
      from pg_catalog.pg_description D
        join pg_catalog.pg_class C on C.oid = D.objoid
      where C.relnamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(D.xmin)
      limit 1
    )
    union all
    (
    select D.xmin as last_tx
      from pg_catalog.pg_description D
        join pg_catalog.pg_constraint C on C.oid = D.objoid
      where C.connamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(D.xmin)
      limit 1
    )
    union all
    (
    select D.xmin as last_tx
      from pg_catalog.pg_description D
        join pg_catalog.pg_proc P on P.oid = D.objoid
      where P.pronamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(D.xmin)
      limit 1
    )
    union all
    (
    select D.xmin as last_tx
      from pg_catalog.pg_description D
        join pg_catalog.pg_type T on T.oid = D.objoid
      where T.typnamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(D.xmin)
      limit 1
    )
    union all
    (
    select D.xmin as last_tx
      from pg_catalog.pg_description D
        join pg_catalog.pg_operator O on O.oid = D.objoid
      where O.oprnamespace = pg_catalog.oid(:schema_id)
      order by pg_catalog.age(D.xmin)
      limit 1
    )
  ) X
  order by pg_catalog.age(X.last_tx)
  limit 1
) C
;


---- ListExistentSchemaComments ----
select D.objoid id, D.objsubid sub_id
from pg_catalog.pg_description D
  join pg_catalog.pg_class C on D.objoid = C.oid
where C.relnamespace = pg_catalog.oid(:schema_id) and C.relkind != 'c'
union all
select T.oid id, D.objsubid
from pg_catalog.pg_description D
  join pg_catalog.pg_type T on T.oid = D.objoid or T.typrelid = D.objoid
  left join pg_catalog.pg_class C on T.typrelid = C.oid
where T.typnamespace = pg_catalog.oid(:schema_id) and (C.relkind = 'c' or C.relkind is null)
union all
select D.objoid id, D.objsubid
from pg_catalog.pg_description D
  join pg_catalog.pg_constraint C on D.objoid = C.oid
where C.connamespace = pg_catalog.oid(:schema_id)
union all
select D.objoid id, D.objsubid
from pg_catalog.pg_description D
  join pg_catalog.pg_proc P on P.oid = D.objoid
where P.pronamespace = pg_catalog.oid(:schema_id)
union all
select D.objoid id, D.objsubid
from pg_catalog.pg_description D
  join pg_catalog.pg_operator O on O.oid = D.objoid
where O.oprnamespace = pg_catalog.oid(:schema_id)
;


---- RetrieveSchemaComments ----
select D.objoid id, C.relkind as kind, D.objsubid sub_id, D.description
from pg_catalog.pg_description D
  join pg_catalog.pg_class C on D.objoid = C.oid
where C.relnamespace = pg_catalog.oid(:schema_id) and C.relkind != 'c'
#INC> and pg_catalog.age(D.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
union all
select T.oid id, 'T' as kind, D.objsubid sub_id, D.description
from pg_catalog.pg_description D
  join pg_catalog.pg_type T on T.oid = D.objoid or T.typrelid = D.objoid
  left join pg_catalog.pg_class C on T.typrelid = C.oid
where T.typnamespace = pg_catalog.oid(:schema_id) and (C.relkind = 'c' or C.relkind is null)
#INC> and pg_catalog.age(D.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
union all
select D.objoid id, cast(translate(C.contype, 'pufc', 'kkxz') as "char") as kind, D.objsubid sub_id, D.description
from pg_catalog.pg_description D
  join pg_catalog.pg_constraint C on D.objoid = C.oid
where C.connamespace = pg_catalog.oid(:schema_id)
#INC> and pg_catalog.age(D.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
union all
select D.objoid id, 'F' as kind, D.objsubid sub_id, D.description
from pg_catalog.pg_description D
  join pg_catalog.pg_proc P on P.oid = D.objoid
where P.pronamespace = pg_catalog.oid(:schema_id)
#INC> and pg_catalog.age(D.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
union all
select D.objoid id, 'O' as kind, D.objsubid sub_id, D.description
from pg_catalog.pg_description D
  join pg_catalog.pg_operator O on O.oid = D.objoid
where O.oprnamespace = pg_catalog.oid(:schema_id)
#INC> and pg_catalog.age(D.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))


---- ListExistentClasses ----
select distinct oid
from pg_catalog.pg_type
where typnamespace = pg_catalog.oid(:schema_id)
union
select distinct oid
from pg_catalog.pg_class
where relnamespace = pg_catalog.oid(:schema_id)
union
select distinct oid
from pg_catalog.pg_proc
where pronamespace = pg_catalog.oid(:schema_id)
union
select distinct oid
from pg_catalog.pg_operator
where oprnamespace = pg_catalog.oid(:schema_id)
union
select distinct oid
from pg_catalog.pg_constraint
where connamespace = pg_catalog.oid(:schema_id)
;


---- RetrieveStates ----
select distinct oid, pg_catalog.int8in(pg_catalog.xidout(xmin)) xmin
from pg_catalog.pg_type
where oid in (OIDS)
union
select distinct oid, pg_catalog.int8in(pg_catalog.xidout(xmin)) xmin
from pg_catalog.pg_class
where oid in (OIDS)
union
select distinct oid, pg_catalog.int8in(pg_catalog.xidout(xmin)) xmin
from pg_catalog.pg_proc
where oid in (OIDS)
union
select distinct oid, pg_catalog.int8in(pg_catalog.xidout(xmin)) xmin
from pg_catalog.pg_operator
where oid in (OIDS)
union
select distinct oid, pg_catalog.int8in(pg_catalog.xidout(xmin)) xmin
from pg_catalog.pg_constraint
where oid in (OIDS)
union
select distinct oid, pg_catalog.int8in(pg_catalog.xidout(xmin)) xmin
from pg_catalog.pg_namespace
where oid in (OIDS)
union
select distinct oid, pg_catalog.int8in(pg_catalog.xidout(xmin)) xmin
from pg_catalog.pg_database
where oid in (OIDS)
;


---- RetrieveDataTypes ----
select T.oid as type_id,
       T.xmin as type_state_number,
       T.typname as type_name,
       T.typtype as type_sub_kind,
       'X' as type_category,
       T.typrelid as class_id,
       T.typbasetype as base_type_id,
       case when T.typtype in ('c','e') then null
            else pg_catalog.format_type(T.typbasetype, T.typtypmod) end as type_def,
       T.typdefault as default_expression,
       T.typnotnull as mandatory
from pg_catalog.pg_type T
         left outer join pg_catalog.pg_class C
             on T.typrelid = C.oid
where T.typnamespace = pg_catalog.oid(:schema_id)
  #INC> and pg_catalog.age(T.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
  and (T.typtype in ('d','e') or C.relkind = 'c'::"char" or T.typtype = 'b' and T.typelem = 0)
order by 1
;


---- RetrieveTables ----
with backup_keys as (
       select pg_catalog.split_part(key, '_', 5) as table_id,
              value
       from pg_conf
       where pg_catalog.split_part(key, '_', 4) = (select oid from pg_database
                                        where datname = pg_catalog.current_database())
       and key like 'pg_class_backup_%'
       and value = 'NO'
)
select T.relkind as table_kind,
       T.relname as table_name,
       T.oid as table_id,
       T.xmin as table_state_number,
       T.relhasoids as table_with_oids,
       T.relnamespace as tablespace_id,
       T.reldiststyle as dist_style,
       (case when BK.value = 'NO' then false else true end) as bckp,
       (case when T.relkind = 'v' and T.relnatts = 0 then true else false end) as is_boundless_view,
       pg_catalog.pg_get_userbyid(T.relowner) as "owner"
from pg_catalog.pg_class T
left outer join backup_keys BK on (T.oid = BK.table_id)
where relnamespace = pg_catalog.oid(:schema_id)
  and relkind in ('r', 'm', 'v')
  #INC> and pg_catalog.age(T.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
order by table_kind, table_id
;


---- RetrieveExternalTables ----
select T.tablename as table_name,
       T.location,
       T.input_format,
       T.output_format,
       T.serialization_lib,
       T.serde_parameters as serde_properties,
       T.parameters as props
from pg_catalog.svv_external_tables T
where T.schemaname = :schema_name
;


---- RetrieveStructAttributes ----
with types      as (select distinct
                           T.oid as type_id,
                           C.oid as class_id
                    from pg_catalog.pg_type T
                    join pg_catalog.pg_class C
                      on T.typrelid = C.oid
                    join pg_catalog.pg_attribute A
                      on C.oid = A.attrelid
                    where T.typnamespace = pg_catalog.oid(:schema_id)
                    #INC> and (pg_catalog.age(C.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))) or pg_catalog.age(A.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))))
                    and T.typrelid = C.oid
                    and T.typtype = 'c'::"char"
                    and relkind = 'c'::"char"),
     attributes as (select A.attrelid as class_id,
                           A.attnum as att_position,
                           A.attname as att_name,
                           pg_catalog.format_type(A.atttypid,A.atttypmod) as att_type
                    from pg_catalog.pg_attribute A
                    where A.attisdropped is null or not A.attisdropped)
select type_id, att_position, att_name, att_type
from types natural join attributes
order by type_id::bigint, att_position
;


---- RetrieveColumns ----
with T as ( select distinct T.oid as table_id, T.relname as table_name
            from pg_catalog.pg_class T,
                 pg_catalog.pg_attribute A
            where T.relnamespace = pg_catalog.oid(:schema_id)
              and T.relkind in ('r', 'm', 'v')
              #INC> and (pg_catalog.age(T.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))) or pg_catalog.age(A.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))))
              and A.attrelid = T.oid )
select T.table_id,
       C.attnum as column_position,
       C.attname as column_name,
       C.xmin as column_state_number,
       C.atttypmod as type_mod,
       C.attndims as dimensions_number,
       pg_catalog.format_type(C.atttypid, C.atttypmod) as type_spec,
       C.attnotnull as mandatory,
       D.adsrc as column_default_expression,
       C.attisdropped as column_is_dropped,
       pg_catalog.format_encoding(C.attencodingtype::integer) as encoding,
       C.attisdistkey as distkey,
       C.attsortkeyord as sortkeyord
from T
  inner join pg_catalog.pg_attribute C on T.table_id = C.attrelid
  left outer join pg_catalog.pg_attrdef D on (C.attrelid, C.attnum) = (D.adrelid, D.adnum)
where attnum > 0
  and not C.attisdropped
order by table_id, attnum
;


---- RetrieveExternalTablesColumns ----
select C.tablename as table_name,
       C.columnnum as position,
       C.columnname as column_name,
       C.external_type as data_type,
       C.part_key as partition_key
from pg_catalog.svv_external_columns C
where C.schemaname = :schema_name
;


---- RetrieveBoundlessViewsColumns ----
select view_name,
       col_num as position,
       col_name as column_name,
       col_type as column_type
from pg_get_late_binding_view_cols() cols(view_schema name, view_name name, col_name name, col_type varchar, col_num int)
where view_schema = :schema_name
;


---- RetrieveConstraints ----
with T as ( select oid as table_id,
                   relkind as table_kind,
                   xmin as table_state_id
            from pg_catalog.pg_class
            where relkind in ('r','v')
              and relnamespace = pg_catalog.oid(:schema_id) ),
     C as ( select conrelid as table_id,
                   oid::bigint as con_id,
                   xmin as con_state_id,
                   conname as con_name,
                   contype as con_kind,
                   conkey as con_columns,
                   confrelid as ref_table_id,
                   confkey as ref_columns,
                   consrc as con_expression
            from pg_catalog.pg_constraint
            where contype in ('p','u','f','c')
              and connamespace = pg_catalog.oid(:schema_id) )
select table_id,
       table_kind,
       con_id,
       pg_catalog.int8in(pg_catalog.xidout(con_state_id)) as con_state_id,
       con_name,
       con_kind,
       '{' || pg_catalog.array_to_string(con_columns, ',') || '}' as con_columns,
       ref_table_id,
       con_expression,
       '{' || pg_catalog.array_to_string(ref_columns, ',') || '}' as ref_columns
from T natural join C
#INC:
 where pg_catalog.age(table_state_id) < pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))) or
       pg_catalog.age(con_state_id) < pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
#.
order by pg_catalog.strpos('pufc', con_kind)
;


---- RetrieveUsedArgumentTypes ----
with schema_procs as (select prorettype, proargtypes
                      from pg_catalog.pg_proc
                      where pronamespace = pg_catalog.oid(:schema_id)
                        and pg_catalog.int8in(pg_catalog.xidout(xmin)) > :tx #. ),
     schema_opers as (select oprleft, oprright, oprresult
                      from pg_catalog.pg_operator
                      where oprnamespace = pg_catalog.oid(:schema_id)
                        and pg_catalog.int8in(pg_catalog.xidout(xmin)) > :tx #. ),
     schema_aggregates as (select A.aggtranstype
                           from pg_catalog.pg_aggregate A
                           join pg_catalog.pg_proc P
                             on A.aggfnoid = P.oid
                           where P.pronamespace = :schema_id::oid
                           #INC: and (pg_catalog.age(A.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))) or pg_catalog.age(P.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))) ) #. ),
     schema_arg_types_arrays as (select pg_catalog.string_to_array(pg_catalog.textin(pg_catalog.oidvectorout(proargtypes)), ' ') as type_ids
                                 from schema_procs),
     array_idxs as (select pg_catalog.generate_series(1,
                     (select pg_catalog.max(pg_catalog.array_upper(type_ids, 1))
                      from schema_arg_types_arrays)
                   ) as i),
     schema_arg_types as ( select prorettype as type_id
                           from schema_procs
                           union
                           select A.type_ids[i]::oid AS type_id
                           from array_idxs
                           inner join schema_arg_types_arrays A ON array_idxs.i <= pg_catalog.array_upper(type_ids, 1)
                           union
                           select oprleft as type_id
                           from schema_opers
                           where oprleft is not null
                           union
                           select oprright as type_id
                           from schema_opers
                           where oprright is not null
                           union
                           select oprresult as type_id
                           from schema_opers
                           where oprresult is not null
                           union
                           select aggtranstype::oid as type_id
                           from schema_aggregates
                           )
select type_id, pg_catalog.format_type(type_id, null) as type_spec
from schema_arg_types
where type_id <> 0
;


---- RetrieveRoutines ----
with languages as (select oid as lang_oid, lanname as lang
                   from pg_catalog.pg_language),
     routines as (select proname as r_name,
                         prolang as lang_oid,
                         oid as r_id,
                         xmin as r_state_number,
                         proargnames as arg_names,
                         null::varchar[] as arg_modes,
                         string_to_array(pg_catalog.textin(pg_catalog.oidvectorout(proargtypes)), ' ')::int8[] as in_arg_types,
                         null::int8[] as all_arg_types,
                         null as arg_defaults,
                         0 as arg_variadic_id,
                         prorettype as ret_type_id,
                         proretset as ret_set,
                         'f' as kind,
                         provolatile as volatile_kind,
                         false as is_strict,
                         false as is_security_definer,
                         null::text[] as configuration_parameters,
                         0 as cost,
                         0 as rows,
                         false as is_leakproof,
                         null as concurrency_kind
                  from pg_catalog.pg_proc
                  where pronamespace = pg_catalog.oid(:schema_id)
                    and not proisagg
                   #INC: and pg_catalog.age(xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))) #.)
select *
from routines natural join languages
;


---- RetrieveAggregates ----
with procedures as (
  select P.oid as function_id,
         pg_catalog.quote_ident(N.nspname) || '.' || pg_catalog.quote_ident(P.proname) as function_name,
         P.prorettype as return_type
  from pg_catalog.pg_proc P
  join pg_catalog.pg_namespace N
    on P.pronamespace = N.oid
)
select P.oid as aggregate_id,
       P.proname as aggregate_name,
       P.proargnames as arg_names,
       string_to_array(pg_catalog.textin(pg_catalog.oidvectorout(P.proargtypes)), ' ')::int8[] as in_arg_types,
       A.aggtransfn::oid as aggregate_function_id,
       case when A.aggtransfn::oid = 0 then null else PR.function_name end as aggregate_function_name,
       A.aggtranstype::oid as transition_type,
       A.aggfinalfn::oid as final_function_id,
       case when A.aggfinalfn::oid = 0 then null else PF.function_name end as final_function_name,
       case when A.aggfinalfn::oid = 0 then 0 else PF.return_type end as final_return_type,
       A.agginitval as initial_value
from pg_catalog.pg_aggregate A
join pg_catalog.pg_proc P
  on A.aggfnoid = P.oid
left outer join procedures PR
  on A.aggtransfn = PR.function_id
left outer join procedures PF
  on A.aggfinalfn = PF.function_id
where P.pronamespace = :schema_id::oid
#INC> and (pg_catalog.age(A.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))) or pg_catalog.age(P.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx))))


---- RetrieveOperators ----
select O.oid as op_id,
       oprname as op_name,
       oprkind as op_kind,
       oprleft as arg_left_type_id,
       oprright as arg_right_type_id,
       oprresult as arg_result_type_id,
       oprcode as func_main
from pg_catalog.pg_operator O
where oprnamespace = pg_catalog.oid(:schema_id)
  #INC> and pg_catalog.age(xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
;


---- RetrieveDescriptions ----
select T.relkind as table_kind,
       T.oid as table_id,
       D.objsubid as column_position,
       D.description
from pg_catalog.pg_class T,
     pg_catalog.pg_description D
where T.relnamespace = pg_catalog.oid(:schema_id)
  and T.relkind in ('r', 'm', 'v')
  and T.oid = D.objoid
  #INC> and pg_catalog.age(D.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
order by table_id, column_position
;


---- RetrieveViewSources ----
select T.relkind as view_kind,
       T.oid as view_id,
       pg_catalog.pg_get_viewdef(T.oid) as source_text
from pg_catalog.pg_class T,
     pg_catalog.pg_namespace N
where N.oid = pg_catalog.oid(:schema_id)
  and T.relnamespace = N.oid
  and T.relkind in ('m','v')
order by pg_catalog.int8in(pg_catalog.xidout(T.xmin))
;


---- RetrieveFunctionSources ----
with system_languages as ( select oid as lang
                           from pg_catalog.pg_language
                           where lanname in ('c','internal') )
select oid as id,
       (select distinct pg_catalog.array_to_string(ARRAY(select (case when arg_names is null then '' else arg_names[k] + ' ' end) + pg_catalog.format_type(T.oid, null)
                                                from pg_catalog.generate_series(1, pg_catalog.array_upper(arg_types, 1)) as k
                                                join pg_catalog.pg_type T ON T.oid = arg_types[k]
                                                order by k), ', ')
          from (select pg_catalog.string_to_array(pg_catalog.textin(pg_catalog.oidvectorout(PGPC.proargtypes)), ' ') arg_types,
                       PGPC.proargnames arg_names
                  from pg_proc PGPC
                  where PGPC.oid = PC.oid) oids_array) as arguments_def,
       (select distinct pg_catalog.format_type(PGT.oid, null)
          from pg_catalog.pg_type PGT
          where PGT.oid = PC.prorettype) as result_def,
       prosrc as source_text
from pg_catalog.pg_proc PC
where pronamespace = pg_catalog.oid(:schema_id)
  #INC> and pg_catalog.age(xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:src_tx)))
  and not proisagg
  and prolang not in (select lang from system_languages)
  and prosrc is not null
;


---- ListReferencingSchemas ----
select distinct connamespace as schema_id
from pg_catalog.pg_constraint F,
     pg_catalog.pg_class O
where F.contype = 'f'
  and F.confrelid = O.oid
  and O.relnamespace in (SCHEMAIDS)
;